#
# spec file for package wofi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wofi
Version:        1.4.1
Release:        1.3
Summary:        Launcher for wlroots compositors
License:        GPL-3.0-only
URL:            https://hg.sr.ht/~scoopta/wofi
Source:         https://hg.sr.ht/~scoopta/wofi/archive/v%{version}.tar.gz
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(wayland-client)

%description
Wofi is a launcher/menu program for wlroots based wayland compositors such as sway.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
Headers for the wofi API which are needed to build wofi plugins.

%prep
%autosetup -p1 -n wofi-v%{version}

%build
%meson
%meson_build

%install
%meson_install

%files
%license COPYING.md
%doc README.md
%{_bindir}/wofi
%{_mandir}/man?/%{name}*

%files devel
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}*

%changelog
* Mon Feb 12 2024 Jan Baier <jbaier@suse.com>
- update to 1.4.1:
  * Added wofi_exit(). This allows correct handling of custom exit status codes
    on non-glibc systems. This function should always be used for exiting wofi
    as libc exit() will no longer correctly handle error situations.
  * Changed the function signature of config_get_mnemonic(). This new signature
    uses the correct types so that the default argument promotions caused by
    varargs is in spec.
* Thu Feb  8 2024 Jan Baier <jbaier@suse.com>
- update to 1.4:
  * Added the config option drun-disable_prime to disable prime GPU offloading
  * Updated meson command in readme
  * Added wezterm to the default terminal list and moved termite to the end of the sane terminal section since it's now deprecated
  * Updated the man pages with the new terminal order
  * Refactor key mapping modifier logic
  * Add return codes for custom keys
  * on_exit_set_custom_key_return_code() now flushes stdio, this fixes #197
  * Fixed #193. drun mode now respects Hidden
  * Add `#expander` selector so expanded actions can be themed
  * Rename `#expander` to `#expander-box`
  * Added documentation for key_custom_n
  * Fixed bug reported in https://github.com/swaywm/sway/issues/7915
  * Fixed malloc for pre_display_exec
  * Forgot to cleanup zombie processes
  * Fixed closing the file handle when pre_display_exec=true
  * Added pre_display_exec which allows pre_display_cmd to be directly executed with fork/exec instead of through the shell
  * Fixed segfault when running non shell safe inputs with --pre-display-cmd and --allow-images
  * Added the drun-print_desktop_file option
  * Fixed weird tabbing behavior
  * Fixed indentation
  * Make sure that the first calculation of percent size is done when the window is visible
  * Add documentation for `#expander-box`
* Thu Nov 24 2022 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.3:
  * Fixed percentage based window sizing
  * added support for --pre-display-cmd / -r
  * Add fuzzy filtering
  * Implement multi-contains matching algorithm
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to 1.2.4:
  * Fixed key_submit not properly working with multi-action entires
  * drun mode now removes field codes when printing the command
  * drun should no longer crash when encountering invalid cache entries
  * Moved the call to exit() outside the else as otherwise wofi won't exit when printing the command
* Fri Nov 13 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.2.3:
  * Fixed wofi with new wlroots not allowing 0 width/height with
    unanchored surfaces
* Tue Sep  1 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Update to v1.2.2
  * Added print_command to run
  * widget_builder now only lets you assign classes.
    The name will be consistent with the image escape system
  * data: will now be correctly handled
  * Added layer config option
  * Added layer config option
  * The img "escapes" should now correctly deal with HiDPI
  * Wofi now loads modes multi-threaded, this should decrease startup times
  * Added --search
  * Added support for the PrefersNonDefaultGPU desktop entry flag
  * Wofi will now keep its percentage size even when moving between monitors
  * Added display_generic option to drun
  * Added img-noscale
  * Added support for purism virtual keyboards
  * Added key_hide_search
  * Added key_expand
  * Added alacritty to the default terminal list
  * Added page up/down support
  * number of other fixes
* Thu Jun  4 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Switch from URL-based Source line to _service file
  * remote couldn't provide stable source ball
* Mon Apr 20 2020 Jan Engelhardt <jengelh@inai.de>
- Switch to URL-based Source line. Use %%autosetup. Improve
  description of wofi-devel.
* Wed Apr 15 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Updated spec file to use general meson macros
- Added devel package as default meson build does it
- Update to version v1.1.2:
  * Wofi properly shuts down if its window is closed in normal
    window mode
  * Removed threads from the dependencies
  * Pressing a key with no modifier which is bound with a
    modifier will now correctly focus the search box
  * Added support for using \t as a separator in dmenu mode
  * Modes are no longer loaded on their own thread
  * Replaced 1 with TRUE when setting
    gtk-application-prefer-dark-theme
  * Removed debug print
  * add switch to use the dark gtk theme
* Sat Nov 16 2019 Alexander Graul <agraul@suse.com>
- Initial Package
